@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -18,6 +18,7 @@
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
+#include <common.h>
 
 void
 grad_app_setup()
@@ -29,4 +30,5 @@ grad_app_setup()
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 #endif
+	grad_set_logger(grad_default_logger);
 }
