@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -13,9 +13,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -35,7 +36,7 @@
 #include <netinet/in.h>
 #include <net/if.h>
 
-#include <radius.h>
+#include <radlib.h>
 
 #if defined(O_NONBLOCK)
 # define FCNTL_NONBLOCK O_NONBLOCK
@@ -49,16 +50,16 @@
  * Put a socket on a non-blocking mode
  */
 int
-set_nonblocking(int fd)
+grad_set_nonblocking(int fd)
 {
         int flags;
 
         if ((flags = fcntl(fd, F_GETFL, 0)) < 0) {
-                radlog(L_ERR|L_PERROR, "F_GETFL");
+                grad_log(L_ERR|L_PERROR, "F_GETFL");
                 return -1;
         }
         if (fcntl(fd, F_SETFL, flags | FCNTL_NONBLOCK) < 0) {
-                radlog(L_ERR|L_PERROR, "F_SETFL");
+                grad_log(L_ERR|L_PERROR, "F_SETFL");
                 return -1;
         }
         return 0;
@@ -70,7 +71,7 @@ set_nonblocking(int fd)
  * Return maximum number of file descriptors available
  */
 int
-getmaxfd()
+grad_max_fd()
 {
 #if defined(HAVE_GETDTABLESIZE)
         return getdtablesize();
@@ -85,10 +86,10 @@ getmaxfd()
 #endif
 }
 
-static UINT4
-get_first_ip_nameindex()
+static grad_uint32_t
+grad_first_ip_nameindex()
 {
-	UINT4 ip = INADDR_ANY;
+	grad_uint32_t ip = INADDR_ANY;
 #ifdef SIOCGIFCONF
 	struct ifreq *ifr, *end, *cur;
 	struct ifconf ifc;
@@ -136,7 +137,7 @@ get_first_ip_nameindex()
 
 		sinp = (struct sockaddr_in *)&cur->ifr_addr;
 		if (sinp->sin_family == AF_INET) {
-			UINT4 n = ntohl(sinp->sin_addr.s_addr);
+			grad_uint32_t n = ntohl(sinp->sin_addr.s_addr);
 
 			if (n != INADDR_LOOPBACK) {
 				ip = n;
@@ -151,44 +152,44 @@ get_first_ip_nameindex()
 	return ip;
 }
 
-static UINT4
-get_first_ip_hostname()
+static grad_uint32_t
+grad_first_ip_hostname()
 {
-	UINT4 ip = INADDR_ANY;
+	grad_uint32_t ip = INADDR_ANY;
 	char *name;
 	int name_len = 256;
 	int status;
 
-	name = emalloc(name_len);
+	name = grad_emalloc(name_len);
 	while (name
 	       && (status = gethostname(name, name_len)) == 0
 	       && !memchr(name, 0, name_len)) {
 		name_len *= 2;
-		name = erealloc(name, name_len);
+		name = grad_erealloc(name, name_len);
 	}
 	if (status == 0) 
-		ip = ip_gethostaddr(name);
-	efree(name);
+		ip = grad_ip_gethostaddr(name);
+	grad_free(name);
 	return ip;
 }
 
-UINT4
-get_first_ip()
+grad_uint32_t
+grad_first_ip()
 {
-	UINT4 ip = INADDR_ANY;
+	grad_uint32_t ip = INADDR_ANY;
 
-	ip = get_first_ip_nameindex();
+	ip = grad_first_ip_nameindex();
 	if (ip == INADDR_ANY)
 		/* Too bad. Try to use older approach */
-		ip = get_first_ip_hostname();
+		ip = grad_first_ip_hostname();
 	
 	return ip;
 }
 
 #ifdef HAVE_SIGACTION
 
-signal_handler_t
-rad_set_signal(int sig, signal_handler_t sighandler)
+grad_signal_handler_t
+grad_set_signal(int sig, grad_signal_handler_t sighandler)
 {
 	struct sigaction act, oact;
 	
@@ -204,22 +205,22 @@ rad_set_signal(int sig, signal_handler_t sighandler)
 }
 
 void
-rad_reset_signal(int sig ARG_UNUSED, signal_handler_t sighandler ARG_UNUSED)
+grad_reset_signal(int sig ARG_UNUSED, grad_signal_handler_t sighandler ARG_UNUSED)
 {
 }
 
 #else
 
-signal_handler_t
-rad_set_signal(int sig, signal_handler_t sighandler)
+grad_signal_handler_t
+grad_set_signal(int sig, grad_signal_handler_t sighandler)
 {
 	return signal(sig, sighandler);
 }
 
 void
-rad_reset_signal(int sig ARG_UNUSED, signal_handler_t sighandler ARG_UNUSED)
+grad_reset_signal(int sig, grad_signal_handler_t sighandler)
 {
-	rad_set_signal(sig, sighandler);
+	grad_set_signal(sig, sighandler);
 }
 #endif
 
