@@ -97,13 +97,13 @@
 #line 1 "users.y"
 
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -136,8 +136,9 @@
 #include <errno.h>
 #include <sys/wait.h>
 
-#include <common.h>
-
+#include <radlib.h>
+#include "intprops.h"
+	
 #define YYMAXDEPTH 10
 
 static grad_locus_t start_loc;
@@ -171,7 +172,7 @@ extern int uyylex();
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 68 "users.y"
+#line 69 "users.y"
 {
         char *string;
         grad_matching_rule_t *rule;
@@ -181,8 +182,8 @@ typedef union YYSTYPE
         grad_avp_t *pair;
         enum grad_operator op;
 }
-/* Line 193 of yacc.c.  */
-#line 186 "users_gram.c"
+/* Line 187 of yacc.c.  */
+#line 187 "users_gram.c"
 	YYSTYPE;
 # define uyystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -195,7 +196,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 199 "users_gram.c"
+#line 200 "users_gram.c"
 
 #ifdef short
 # undef short
@@ -484,9 +485,9 @@ static const uyytype_int8 uyyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const uyytype_uint8 uyyrline[] =
 {
-       0,    80,    80,    81,    84,    87,    88,    94,    98,   110,
-     116,   123,   127,   130,   131,   142,   146,   152,   156,   160,
-     164,   168,   172,   178,   179
+       0,    81,    81,    82,    85,    88,    89,    95,    99,   111,
+     117,   124,   128,   131,   132,   143,   147,   153,   157,   161,
+     165,   169,   173,   179,   180
 };
 #endif
 
@@ -1401,27 +1402,27 @@ uyyreduce:
   switch (uyyn)
     {
         case 4:
-#line 85 "users.y"
+#line 86 "users.y"
     {
            }
     break;
 
   case 6:
-#line 89 "users.y"
+#line 90 "users.y"
     {
                    grad_parser_lex_sync(); uyyerrok; uyyclearin;
            }
     break;
 
   case 7:
-#line 95 "users.y"
+#line 96 "users.y"
     {
                    add_entry(closure, &start_loc, (uyyvsp[(1) - (2)].string), (uyyvsp[(2) - (2)].descr).lhs, (uyyvsp[(2) - (2)].descr).rhs);
            }
     break;
 
   case 8:
-#line 99 "users.y"
+#line 100 "users.y"
     {
                    grad_log(L_ERR, _("discarding user `%s'"), (uyyvsp[(1) - (2)].string));
                    if (grad_parser_lex_sync() <= 0)
@@ -1434,14 +1435,14 @@ uyyreduce:
     break;
 
   case 9:
-#line 111 "users.y"
+#line 112 "users.y"
     {
 		   start_loc = grad_parser_source_locus;
            }
     break;
 
   case 10:
-#line 117 "users.y"
+#line 118 "users.y"
     {
                    (uyyval.descr).lhs = (uyyvsp[(1) - (2)].pair);
                    (uyyval.descr).rhs = (uyyvsp[(2) - (2)].pair);
@@ -1449,14 +1450,14 @@ uyyreduce:
     break;
 
   case 11:
-#line 124 "users.y"
+#line 125 "users.y"
     {
                    (uyyval.pair) = NULL;
            }
     break;
 
   case 14:
-#line 132 "users.y"
+#line 133 "users.y"
     {
                    if ((uyyvsp[(1) - (3)].pair)) {
                            if ((uyyvsp[(3) - (3)].pair)) 
@@ -1468,56 +1469,56 @@ uyyreduce:
     break;
 
   case 15:
-#line 143 "users.y"
+#line 144 "users.y"
     {
                    (uyyval.pair) = grad_create_pair0((uyyvsp[(1) - (3)].string), (uyyvsp[(2) - (3)].op), (uyyvsp[(3) - (3)].string));   
            }
     break;
 
   case 16:
-#line 147 "users.y"
+#line 148 "users.y"
     {
                    YYERROR;
            }
     break;
 
   case 17:
-#line 153 "users.y"
+#line 154 "users.y"
     {
                    (uyyval.op) = grad_operator_equal;
            }
     break;
 
   case 18:
-#line 157 "users.y"
+#line 158 "users.y"
     {
                    (uyyval.op) = grad_operator_less_than;
            }
     break;
 
   case 19:
-#line 161 "users.y"
+#line 162 "users.y"
     { 
                    (uyyval.op) = grad_operator_greater_than;
            }
     break;
 
   case 20:
-#line 165 "users.y"
+#line 166 "users.y"
     {
                    (uyyval.op) = grad_operator_not_equal;
            }
     break;
 
   case 21:
-#line 169 "users.y"
+#line 170 "users.y"
     {
                    (uyyval.op) = grad_operator_less_equal;
            }
     break;
 
   case 22:
-#line 173 "users.y"
+#line 174 "users.y"
     {
                    (uyyval.op) = grad_operator_greater_equal;
            }
@@ -1525,7 +1526,7 @@ uyyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1529 "users_gram.c"
+#line 1530 "users_gram.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", uyyr1[uyyn], &uyyval, &uyyloc);
@@ -1739,7 +1740,7 @@ uyyreturn:
 }
 
 
-#line 182 "users.y"
+#line 183 "users.y"
 
 
 int
@@ -1872,8 +1873,11 @@ grad_create_pair(grad_locus_t *loc, char *name,
 
 			if (x) {
 				char *s;
-				asprintf(&s, "%lu+%%{NAS-Port-Id}",
-					 pair->avp_lvalue);
+				char buf[INT_STRLEN_BOUND(long)];
+				grad_longtostr(pair->avp_lvalue,
+					       buf, sizeof buf);
+				grad_astrcat(&s, buf, "+", "%{NAS-Port-Id}",
+					     NULL);
 				pair->avp_strvalue = grad_estrdup(s);
 				pair->avp_strlength = strlen(pair->avp_strvalue);
 				pair->eval_type = grad_eval_interpret;
