@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -13,9 +14,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation, 
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -39,7 +41,8 @@
 #include <pwd.h>
 #include <grp.h>
 
-#include <common.h>
+#include <radlib.h>
+#include "intprops.h"
 
 grad_request_t *
 grad_request_alloc()
@@ -69,7 +72,7 @@ grad_parse_time_string(char *valstr, struct tm *tm)
 
         /* Get the month */
         for (i = 0; i < 12; i++) {
-                if (strncasecmp(months[i], valstr, 3) == 0) {
+                if (grad_c_strncasecmp(months[i], valstr, 3) == 0) {
                         tm->tm_mon = i;
                         break;
                 }
@@ -159,12 +162,37 @@ grad_mkfilename3(char *dir, char *subdir, char *name)
 {
         int len = strlen(dir) + strlen(subdir) + strlen(name);
         char *p = grad_emalloc(len+3); /* two intermediate slashes and
-                                   * terminating zero
-                                   */
+                                        * terminating zero
+                                        */
         sprintf(p, "%s/%s/%s", dir, subdir, name);
         return p;
 }
 
+int
+grad_astrcat(char **pptr, ...)
+{
+	va_list ap;
+	size_t size = 0;
+	char *s, *p;
+	
+	va_start(ap, pptr);
+	while ((s = va_arg(ap, char*)))
+		size += strlen(s);
+	va_end(ap);
+	size++;
+	p = malloc(size);
+	if (!p)
+		return 1;
+	*p = 0;
+	va_start(ap, pptr);
+	while ((s = va_arg(ap, char*)))
+		strcat(p, s);
+	va_end(ap);
+	
+	*pptr = p;
+	return 0;
+}
+
 /* Convert second character of a backslash sequence to its ASCII
    value: */
 int
@@ -180,67 +208,6 @@ grad_decode_backslash(int c)
         return c;
 }
 
-#define to_num(c) \
-  (isdigit(c) ? c - '0' : (isxdigit(c) ? toupper(c) - 'A' + 10 : -1 ))
-
-void
-grad_obstack_grow_backslash_num(struct obstack *stk, char *text,
-				int len, int base)
-{
-	int i;
-	int c = 0;
-
-	for (i = len-1; i >= 0 && text[i] != '\\'; i--)
-		;
-	if (i)
-		obstack_grow(stk, text, i);
-	if (base == 16)
-		i++;
-	for (i++; i < len; i++) 
-		c = c*base + to_num(text[i]);
-	obstack_1grow(stk, c);
-}
-
-
-void
-grad_obstack_grow_backslash(struct obstack *stk, char *text, char **endp)
-{
-	int c, i;
-	
-	switch (text[1]) {
-	case '\\':
-		obstack_1grow(stk, text[1]);
-		text += 2;
-		break;
-		
-	default:
-		c = grad_decode_backslash(text[1]);
-		obstack_1grow(stk, c);
-		text += 2;
-		break;
-		
-	case '0':
-		for (i = 0; i < 3 && isdigit(text[i+1]) && text[i+1] < '8'; i++)
-			;
-		if (i != 3)
-			break;
-		grad_obstack_grow_backslash_num(stk, text, 4, 8);
-		text += 4;
-		break;
-		
-	case 'x':
-	case 'X':
-		for (i = 0; i < 2 && isxdigit(text[i+2]); i++)
-			;
-		if (i != 2)
-			break;
-		grad_obstack_grow_backslash_num(stk, text, 3, 16);
-		text += 3;
-		break;
-	}
-	*endp = text;
-}
-
 void
 grad_string_copy(char *d, char *s, int len)
 {
@@ -475,17 +442,22 @@ grad_format_pair(grad_avp_t *pair, int typeflag, char **savep)
 	}
 	
         if (pair->name)
-                asprintf(&buf1, "%s %s %s%s",
-                         pair->name,
-                         grad_op_to_str(pair->operator),
-			 type,
-                         buf2ptr ? buf2ptr : buf2);
-        else
-                asprintf(&buf1, "%d %s %s%s",
-                         pair->attribute,
-                         grad_op_to_str(pair->operator),
-			 type,
-                         buf2ptr ? buf2ptr : buf2);
+		grad_astrcat(&buf1,
+			     pair->name, " ",
+			     grad_op_to_str(pair->operator), " ",
+			     type,
+			     buf2ptr ? buf2ptr : buf2,
+			     NULL);
+        else {
+		char buf[INT_STRLEN_BOUND (int)];
+
+		grad_inttostr(pair->attribute, buf, sizeof buf);
+                grad_astrcat(&buf1,
+			     buf, " ",
+			     grad_op_to_str(pair->operator), " ",
+			     buf2ptr ? buf2ptr : buf2,
+			     NULL);
+	}
 
         if (buf2ptr)
                 free(buf2ptr);
