@@ -1,12 +1,12 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006 Free Software Foundation, Inc.
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
  
    GNU Radius is distributed in the hope that it will be useful,
@@ -322,15 +322,15 @@ rad_acct_system(radiusd_request_t *radreq, int dowtmp)
                 return 0;
         } else if (status == DV_ACCT_STATUS_TYPE_START ||
                    status == DV_ACCT_STATUS_TYPE_STOP) {
-                GRAD_DEBUG(1,
-                    ("%s: User %s at NAS %s port %d session %-*.*s",
+                GRAD_DEBUG7(1,
+                    "%s: User %s at NAS %s port %d session %-*.*s",
                      status == DV_ACCT_STATUS_TYPE_START ? "start" : "stop",
                      ut.login,
                      grad_nas_ip_to_name(nas_address, buf, sizeof buf),
                      ut.nas_port,
                      sizeof(ut.session_id),
                      sizeof(ut.session_id),
-                     ut.session_id));
+                     ut.session_id);
         }
 
         /* Decide if we should store this record into radutmp/radwtmp.
@@ -345,16 +345,14 @@ rad_acct_system(radiusd_request_t *radreq, int dowtmp)
                 return 0;
 
         if (!ACCT_TYPE(radreq->request->avlist, DV_ACCT_TYPE_SYSTEM)) {
-                GRAD_DEBUG(1,("Acct type system disabled for %s", ut.login));
+                GRAD_DEBUG1(1,"Acct type system disabled for %s", ut.login);
                 return 0;
         }
         
         /* Update radutmp file. */
         rc = grad_utmp_putent(grad_utmp_file, &ut, status);
-        GRAD_DEBUG(1, ("grad_utmp_putent=%d for %s/%s",
-                  rc,
-                  ut.login,
-                  ut.session_id));
+        GRAD_DEBUG3(1, "grad_utmp_putent=%d for %s/%s",
+                    rc, ut.login, ut.session_id);
 
         /* Don't write wtmp if we don't have a username, or
            if this is an update record and the original record
