@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
  
    GNU Radius is distributed in the hope that it will be useful,
@@ -596,14 +597,13 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
         /* Process any prefixes/suffixes. */
         strip_username(1, m->namepair->avp_strvalue, m->user_check, name);
 
-        debug(1,
-	      ("auth_type=%d, userpass=%s, name=%s, password=%s",
-	       auth_type, m->userpass, name,
-	       real_password ? real_password : "NONE"));
+        GRAD_DEBUG4(1, "auth_type=%d, userpass=%s, name=%s, password=%s",
+	            auth_type, m->userpass, name,
+	            real_password ? real_password : "NONE");
 
         switch (auth_type) {
         case DV_AUTH_TYPE_SYSTEM:
-                debug(1, ("  auth: System"));
+                GRAD_DEBUG(1, "auth: System");
                 if (unix_pass(name, m->userpass) != 0)
                         result = auth_fail;
 		else
@@ -612,7 +612,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
 		
         case DV_AUTH_TYPE_PAM:
 #ifdef USE_PAM
-                debug(1, ("  auth: Pam"));
+                GRAD_DEBUG(1, "auth: Pam");
                 /* Provide defaults for authdata */
                 if (authdata == NULL &&
                     (tmp = grad_avl_find(m->user_check, DA_PAM_AUTH)) != NULL) {
@@ -629,7 +629,7 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                 break;
 
         case DV_AUTH_TYPE_CRYPT_LOCAL:
-                debug(1, ("  auth: Crypt"));
+                GRAD_DEBUG(1, "auth: Crypt");
                 if (real_password == NULL) {
                         result = auth_fail;
                         break;
@@ -640,12 +640,12 @@ rad_check_password(radiusd_request_t *radreq, AUTH_MACH *m, time_t *exp)
                         result = auth_fail;
                 else if (strcmp(real_password, pwbuf) != 0)
                         result = auth_fail;
-                debug(1,("pwbuf: %s", pwbuf));
+                GRAD_DEBUG1(1, "pwbuf: %s", pwbuf);
                 grad_free(pwbuf);
                 break;
                 
         case DV_AUTH_TYPE_LOCAL:
-                debug(1, ("  auth: Local"));
+                GRAD_DEBUG(1, "auth: Local");
                 /* Local password is just plain text. */
                 if (auth_item->attribute != DA_CHAP_PASSWORD) {
                         if (real_password == NULL ||
@@ -758,7 +758,7 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
 
         m.namepair = grad_avl_find(m.req->request->avlist, DA_USER_NAME);
 
-        debug(1, ("auth: %s", m.namepair->avp_strvalue)); 
+        GRAD_DEBUG1(1, "auth: %s", m.namepair->avp_strvalue); 
         m.state = as_init;
 
         while (m.state != as_stop) {
@@ -805,7 +805,7 @@ rad_authenticate(radiusd_request_t *radreq, int activefd)
 
 #if RADIUS_DEBUG
 # define newstate(s) do {\
-             debug(2, ("%d -> %d", m->state, s));\
+             GRAD_DEBUG2(2, "%d -> %d", m->state, s);\
              m->state = s;\
   } while (0)
 #else
@@ -888,37 +888,23 @@ sfn_init(AUTH_MACH *m)
 void
 sfn_scheme(AUTH_MACH *m)
 {
-#ifdef USE_SERVER_GUILE
-        grad_avp_t *p;
-        grad_avp_t *reply = NULL;
-        
-        if (!use_guile) {
-                grad_log_req(L_ERR, m->req->request,
-                             _("Guile authentication disabled in config"));
-                newstate(as_reject_cleanup);
-                return;
-        }
+	grad_avp_t *p;
+        grad_avp_t *tmp = NULL;
 
-	grad_avl_move_attr(&reply, &m->user_reply, DA_SCHEME_PROCEDURE);
-        for (p = reply; p; p = p->next) {
-                if (scheme_auth(p->avp_strvalue,
-                                m->req, m->user_check, &m->user_reply)) {
+	grad_avl_move_attr(&tmp, &m->user_reply, DA_SCHEME_PROCEDURE);
+	if (scheme_eval_avl (m->req, m->user_check, tmp, &m->user_reply, &p)) {
+		if (p) {
 			auth_log(m,
 				 _("Login rejected"),
 				 NULL,
 				 _("denied by Scheme procedure "),
 				 p->avp_strvalue);
                         newstate(as_reject);
-                        break;
-                }
-        }
-        grad_avl_free(reply);
-#else
-        grad_log_req(L_ERR, m->req,
-                     _("Guile authentication not available"));
-        newstate(as_reject_cleanup);
-        return;
-#endif
+		} else { /* Empty P means that Guile auth is not available */
+			newstate(as_reject_cleanup);
+		}
+	}
+	grad_avl_free(tmp);
 }
 
 /* Execute an Authentication Failure Trigger, if the one is specified */
@@ -1135,11 +1121,11 @@ sfn_time(AUTH_MACH *m)
                  * User is allowed, but set Session-Timeout.
                  */
                 grad_uint32_t to = set_session_timeout(m, rest);
-                debug(2, ("user %s, span %s, timeout %d, real timeout %d",
-                          m->namepair->avp_strvalue,
-                          m->check_pair->avp_strvalue,
-                          rest,
-			  to));
+                GRAD_DEBUG4(2, "user %s, span %s, timeout %d, real timeout %d",
+                            m->namepair->avp_strvalue,
+                            m->check_pair->avp_strvalue,
+                            rest,
+			    to);
         }
 }
 
@@ -1164,59 +1150,27 @@ sfn_exec_wait(AUTH_MACH *m)
 {
 	int rc;
 	grad_avp_t *p;
-	grad_avp_t *repl = NULL;
+	grad_avp_t *reply = NULL;
+
+	rc = exec_program_wait (m->req, m->check_pair, &reply, &p);
 	
-	for (p = m->check_pair;
-             p;
-             p = grad_avl_find(p->next, DA_EXEC_PROGRAM_WAIT)) {
-		grad_avp_t *tail = NULL;
+	if (rc != 0) {
+		newstate(as_reject);
 
-		if (m->user_reply)
-			for (tail = m->user_reply; tail->next;
-			     tail = tail->next)
-				;
-
-		switch (p->avp_strvalue[0]) {
-		case '/':
-			/* radius_exec_program() returns -1 on
-		   	   fork/exec errors, or >0 if the exec'ed program
-		   	   had a non-zero exit status.
-			 */
-			rc = radius_exec_program(p->avp_strvalue,
-					         m->req,
-					         &m->user_reply,
-					         1);
-			break;
-
-		case '|':
-			rc = filter_auth(p->avp_strvalue+1,
-				         m->req,
-				         &m->user_reply);
-			break;
-
-		default:
-			rc = 1;
+		if (is_log_mode(m, RLOG_AUTH)) {
+			auth_log(m, _("Login incorrect"),
+				 NULL,
+				 _("external check failed: "), 
+				 p->avp_strvalue);
 		}
 
-		if (rc != 0) {
-			newstate(as_reject);
-
-			if (is_log_mode(m, RLOG_AUTH)) {
-				auth_log(m, _("Login incorrect"),
-				         NULL,
-				         _("external check failed: "), 
-                                         p->avp_strvalue);
-		        }
-
-			p = tail->next;
-			tail->next = NULL;
-			grad_avl_free(m->user_reply);
-			m->user_reply = p;
-			if (!grad_avl_find(m->user_reply, DA_REPLY_MESSAGE))
-				auth_format_msg(m, MSG_ACCESS_DENIED);
-			
-			break;
-		}
+		grad_avl_free(m->user_reply);
+		m->user_reply = reply;
+		if (!grad_avl_find(m->user_reply, DA_REPLY_MESSAGE))
+			auth_format_msg(m, MSG_ACCESS_DENIED);
+	} else {
+		grad_avl_merge(&m->user_reply, &reply);
+		grad_avl_free(reply);
 	}
 }
 
@@ -1228,10 +1182,8 @@ sfn_exec_nowait(AUTH_MACH *m)
 	for (p = m->check_pair;
              p;
              p = grad_avl_find(p->next, DA_EXEC_PROGRAM)) {
-		
-		radius_exec_program(m->check_pair->avp_strvalue,
-				    m->req, NULL, 0);
-
+		radius_eval_avp(m->req, p, NULL, 1);
+		radius_exec_program(p->avp_strvalue, m->req, NULL, 0);
 	}
 }
 
@@ -1269,9 +1221,8 @@ sfn_menu_challenge(AUTH_MACH *m)
         radius_send_challenge(m->req, msg, state_value, m->activefd);
         grad_free(msg);
 	
-        debug(1,
-              ("sending challenge (menu %s) to %s",
-               m->check_pair->avp_strvalue, m->namepair->avp_strvalue));
+        GRAD_DEBUG2(1, "sending challenge (menu %s) to %s",
+                    m->check_pair->avp_strvalue, m->namepair->avp_strvalue);
         newstate(as_stop);
 #endif  
 }
@@ -1279,7 +1230,7 @@ sfn_menu_challenge(AUTH_MACH *m)
 void
 sfn_ack(AUTH_MACH *m)
 {
-        debug(1, ("ACK: %s", m->namepair->avp_strvalue));
+        GRAD_DEBUG1(1, "ACK: %s", m->namepair->avp_strvalue);
         
 	radius_eval_avl(m->req, m->user_reply);
 
@@ -1307,7 +1258,7 @@ sfn_reject_cleanup(AUTH_MACH *m)
 void
 sfn_reject(AUTH_MACH *m)
 {
-        debug(1, ("REJECT: %s", m->namepair->avp_strvalue));
+        GRAD_DEBUG1(1, "REJECT: %s", m->namepair->avp_strvalue);
 	radius_eval_avl(m->req, m->user_reply);
         radius_send_reply(RT_ACCESS_REJECT,
                           m->req,
