@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius
-   Copyright (C) 2000,2001,2002,2003,2004,2005 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -255,20 +256,20 @@ converse(int type, struct snmp_session *sp, struct snmp_pdu *pdu, void *closure)
                 switch (vlist->type) {
                 case SMI_STRING:
                         rc = compare(checkp, vlist->var_str);
-                        debug(2, ("(STRING) %s: %d", vlist->var_str, rc));
+                        GRAD_DEBUG2(2, "(STRING) %s: %d", vlist->var_str, rc);
                         break;
                 case SMI_INTEGER:
                 case SMI_COUNTER32:
                 case SMI_COUNTER64:
                         snprintf(buf, sizeof(buf), "%d", vlist->var_int);
                         rc = compare(checkp, buf);
-                        debug(2, ("(INT) %d: %d", vlist->var_int, rc));
+                        GRAD_DEBUG2(2, "(INT) %d: %d", vlist->var_int, rc);
                         break;
                 case SMI_IPADDRESS:
                         grad_ip_iptostr(*(grad_uint32_t*)vlist->var_int, buf);
                         rc = compare(checkp, buf);
-                        debug(2, ("(IPADDR) %#x: %d",
-                                  *(grad_uint32_t*)vlist->var_str, rc));
+                        GRAD_DEBUG2(2, "(IPADDR) %#x: %d",
+                                    *(grad_uint32_t*)vlist->var_str, rc);
                         break;
                 }
 
@@ -355,11 +356,11 @@ snmp_check(struct check_instance *checkp, grad_nas_t *nas)
         snmp_pdu_add_var(pdu, var);
         snmp_free(oid);
 
-        debug(1, ("snmpget: %s:%d %s %s",
-                  peername,
-                  remote_port,
-                  community,
-                  snmp_oid));
+        GRAD_DEBUG4(1, "snmpget: %s:%d %s %s",
+                    peername,
+                    remote_port,
+                    community,
+                    snmp_oid);
 
         checkp->result = rc;
         
@@ -368,7 +369,7 @@ snmp_check(struct check_instance *checkp, grad_nas_t *nas)
         rc = checkp->result;
         snmp_session_close(sp);
         
-        debug(1, ("result: %d", rc));
+        GRAD_DEBUG1(1, "result: %d", rc);
         return rc;
 }
 
@@ -439,8 +440,8 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
                 return -1;
         }
 
-        debug(1, ("finger %s@%s:%d",
-                  namebuf, hp->h_name, ntohs(port)));
+        GRAD_DEBUG3(1, "finger %s@%s:%d",
+                    namebuf, hp->h_name, ntohs(port));
 
         /* have network connection; identify the host connected with */
         memset(&msg, 0, sizeof(msg));
@@ -520,7 +521,7 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
                                 
                                 obstack_1grow(&checkp->stack, 0);
                                 ptr = obstack_finish(&checkp->stack);
-                                debug(2,("got : %s", ptr));
+                                GRAD_DEBUG1(2, "got : %s", ptr);
                                 found = compare(checkp, ptr);
                                 obstack_free(&checkp->stack, ptr);
                                 if (found) 
@@ -541,7 +542,7 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
 
                         obstack_1grow(&checkp->stack, '\n');
                         obstack_1grow(&checkp->stack, 0);
-                        debug(2,("got : %s", ptr));
+                        GRAD_DEBUG1(2, "got : %s", ptr);
                         ptr = obstack_finish(&checkp->stack);
                         found = compare(checkp, ptr);
                 }
@@ -555,7 +556,7 @@ finger_check(struct check_instance *checkp, grad_nas_t *nas)
         /* restore alarm settings */
         alarm(0);
 
-        debug(1, ("result: %d", found));
+        GRAD_DEBUG1(1, "result: %d", found);
         checkp->result = found;
         return found;
 }
