@@ -91,13 +91,13 @@
 #line 1 "config.y"
 
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -177,7 +177,7 @@ void _cfg_free_argv(int argc, cfg_value_t *argv);
 struct cfg_stmt *_cfg_find_keyword(struct cfg_stmt *stmt, char *str);
 static int _get_value(cfg_value_t *arg, int type, void *base);
 
-static struct obstack cfg_obstack;
+static grad_slist_t cfg_slist;
 char *cfg_filename;
 int cfg_line_num;
 static char *buffer;
@@ -216,7 +216,7 @@ typedef union YYSTYPE
 	grad_list_t *vlist;
 	struct cfg_stmt *stmt;
 }
-/* Line 193 of yacc.c.  */
+/* Line 187 of yacc.c.  */
 #line 221 "config.c"
 	YYSTYPE;
 # define ccstype YYSTYPE /* obsolescent; will be withdrawn */
@@ -1900,11 +1900,11 @@ static char *
 copy_alpha()
 {
         do {
-		obstack_1grow(&cfg_obstack, *curp);
+		grad_slist_append_char(cfg_slist, *curp);
                 curp++;
         } while (*curp && isword(*curp));
-	obstack_1grow(&cfg_obstack, 0);
-	return obstack_finish(&cfg_obstack);
+	grad_slist_append_char(cfg_slist, 0);
+	return grad_slist_finish(cfg_slist);
 }
 
 static char *
@@ -1914,17 +1914,17 @@ copy_string()
 
         while (*curp) {
 		if (*curp == '\\') {
-			grad_obstack_grow_backslash(&cfg_obstack, curp, &curp);
+			grad_slist_grow_backslash(cfg_slist, curp, &curp);
 		} else if (*curp == quote) {
                         curp++;
                         break;
                 } else {
-			obstack_1grow(&cfg_obstack, *curp);
+			grad_slist_append_char(cfg_slist, *curp);
 			curp++;
 		}
         } 
-	obstack_1grow(&cfg_obstack, 0);
-	return obstack_finish(&cfg_obstack);
+	grad_slist_append_char(cfg_slist, 0);
+	return grad_slist_finish(cfg_slist);
 }
 
 static int
@@ -1934,20 +1934,20 @@ copy_digit()
 
         if (*curp == '0') {
                 if (curp[1] == 'x' || curp[1] == 'X') {
-			obstack_1grow(&cfg_obstack, *curp);
+			grad_slist_append_char(cfg_slist, *curp);
 			curp++;
-			obstack_1grow(&cfg_obstack, *curp);
+			grad_slist_append_char(cfg_slist, *curp);
 			curp++;
                 }
         }
         
         do {
-		obstack_1grow(&cfg_obstack, *curp);
+		grad_slist_append_char(cfg_slist, *curp);
                 if (*curp++ == '.')
                         dot++;
         } while (*curp && (isdigit(*curp) || *curp == '.'));
-	obstack_1grow(&cfg_obstack, 0);
-	cclval.string = obstack_finish(&cfg_obstack);
+	grad_slist_append_char(cfg_slist, 0);
+	cclval.string = grad_slist_finish(cfg_slist);
         return dot;
 }
 
@@ -2264,6 +2264,14 @@ _get_value(cfg_value_t *arg, int type, void *base)
 
         switch (type) {
         case CFG_INTEGER:
+                *(int*) base = value.v.number;
+                break;
+		
+        case CFG_UNSIGNED:
+                *(unsigned*) base = value.v.number;
+                break;
+		
+        case CFG_SIZE_T:
                 *(size_t*) base = value.v.number;
                 break;
 		
@@ -2355,16 +2363,50 @@ cfg_get_ipaddr(int argc, cfg_value_t *argv, void *block_data,
 	return _get_value(&argv[1], CFG_IPADDR, handler_data);
 }
 
+int
+cfg_get_uint32_t(int argc, cfg_value_t *argv, void *block_data,
+		 void *handler_data)
+{
+	_check_argc(argc, 1);
+	return _get_value(&argv[1], CFG_IPADDR, handler_data);
+}
+
 int
 cfg_get_integer(int argc, cfg_value_t *argv, void *block_data,
 		void *handler_data)
+{
+	int val;
+	int rc;
+	
+	_check_argc(argc, 1);
+	rc = _get_value(&argv[1], CFG_INTEGER, &val);
+	*(int*)handler_data = val;
+	return rc;
+}
+
+int
+cfg_get_unsigned(int argc, cfg_value_t *argv, void *block_data,
+		 void *handler_data)
+{
+	unsigned val;
+	int rc;
+	
+	_check_argc(argc, 1);
+	rc = _get_value(&argv[1], CFG_UNSIGNED, &val);
+	*(unsigned*)handler_data = val;
+	return rc;
+}
+
+int
+cfg_get_size_t(int argc, cfg_value_t *argv, void *block_data,
+	       void *handler_data)
 {
 	size_t val;
 	int rc;
 	
 	_check_argc(argc, 1);
 	rc = _get_value(&argv[1], CFG_INTEGER, &val);
-	*(int*)handler_data = val;
+	*(size_t*)handler_data = val;
 	return rc;
 }
 
@@ -2450,7 +2492,7 @@ cfg_read(char *fname, struct cfg_stmt *syntax, void *data)
                 ccdebug = 0;
         }
 
-	obstack_init(&cfg_obstack);
+	cfg_slist = grad_slist_create();
 	_cfg_run_begin(syntax, data);
 	
         /* Parse configuration */
@@ -2463,7 +2505,7 @@ cfg_read(char *fname, struct cfg_stmt *syntax, void *data)
 		;
 
 	_cfg_free_memory_pool();
-	obstack_free(&cfg_obstack, NULL);
+	grad_slist_free(&cfg_slist);
 
         return 0;
 }       
