@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2001,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2001,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -44,36 +44,35 @@ struct check_datum {
 };
 
 static void TC(unsigned *R, int n);
-static int sym_counter(void *closure, User_symbol *sym);
 static void mark_profile(struct check_datum *datum, User_symbol *sym,
                          char *target_name);
 static void mark_list(struct check_datum *datum, User_symbol *sym, 
                       grad_avp_t *list);
-static int pass1(struct check_datum *datum, User_symbol *sym);
-static int pass2(struct check_datum *datum, User_symbol *sym);
 static void check_dup_attr(grad_avp_t **prev, grad_avp_t *ptr, grad_locus_t *loc);
 
 
-int
-sym_counter(void *closure, User_symbol *sym)
+static int
+sym_counter(void *closure, grad_symbol_t *symbol)
 {
+	User_symbol *sym = (User_symbol *) symbol;
+
         sym->ordnum = (*(int*)closure)++;
         return 0;
 }
 
-void
+static void
 radck_setbit(unsigned *r, unsigned rowsize, unsigned row, unsigned col)
 {
         SETBIT(r + rowsize * row, col);
 }
 
-int
+static int
 radck_bitisset(unsigned *r, unsigned rowsize, unsigned row, unsigned col)
 {
         return BITISSET(r + rowsize * row, col);
 }
 
-void
+static void
 mark_profile(struct check_datum *datum, User_symbol *sym, char *target_name)
 {
         User_symbol *target = (User_symbol*)grad_sym_lookup(datum->symtab, target_name);
@@ -92,7 +91,7 @@ mark_profile(struct check_datum *datum, User_symbol *sym, char *target_name)
                  !strcmp(target->name, target_name));
 }
 
-void
+static void
 mark_list(struct check_datum *datum, User_symbol *sym, grad_avp_t *list)
 {
         grad_avp_t *p;
@@ -105,17 +104,23 @@ mark_list(struct check_datum *datum, User_symbol *sym, grad_avp_t *list)
         }
 }
 
-int
-pass1(struct check_datum *datum, User_symbol *sym)
+static int
+pass1(void *closure, grad_symbol_t *symbol)
 {
+	struct check_datum *datum = closure;
+	User_symbol *sym = (User_symbol *) symbol;
+
         mark_list(datum, sym, sym->check);
         mark_list(datum, sym, sym->reply);
         return 0;
 }
 
-int
-pass2(struct check_datum *datum, User_symbol *sym)
+static int
+pass2(void *closure, grad_symbol_t *symbol)
 {
+	struct check_datum *datum = closure;
+	User_symbol *sym = (User_symbol *) symbol;
+
         if (radck_bitisset(datum->r, datum->rlen, sym->ordnum, sym->ordnum)) {
                 grad_log_loc(L_ERR, &sym->loc,
 			     _("circular dependency for %s"),
@@ -186,11 +191,11 @@ check_dup_attr(grad_avp_t **prev, grad_avp_t *ptr, grad_locus_t *loc)
 static int
 compile_pair(grad_avp_t *pair)
 {
-	if (pair->eval_type == eval_interpret) {
+	if (pair->eval_type == grad_eval_interpret) {
 		char *symname = rewrite_compile(pair->avp_strvalue);
 		if (symname == 0) 
 			return -1;
-		pair->eval_type = eval_compiled;
+		pair->eval_type = grad_eval_compiled;
 		grad_free(pair->avp_strvalue);
 		pair->avp_strvalue = symname;
 		pair->avp_strlength = strlen(symname);
@@ -217,7 +222,7 @@ fix_check_pairs(int cf_file, grad_locus_t *loc, char *name, grad_avp_t **pairs)
                 
                 dict = grad_attr_number_to_dict(p->attribute);
                 if (dict) {
-                        if (!(dict->prop & AF_LHS(cf_file))) {
+                        if (!(dict->prop & GRAD_AF_LHS(cf_file))) {
                                 grad_log_loc(L_ERR, loc,
 					 _("attribute %s not allowed in LHS"),
 					     dict->name);
@@ -283,7 +288,7 @@ fix_check_pairs(int cf_file, grad_locus_t *loc, char *name, grad_avp_t **pairs)
                 }
         }
 
-        if (cf_file != CF_USERS)
+        if (cf_file != GRAD_CF_USERS)
                 return 0;
 
         /*
@@ -412,7 +417,7 @@ fix_reply_pairs(int cf_file, grad_locus_t *loc, char *name, grad_avp_t **pairs)
         for (p = *pairs; p; p = p->next) {
                 dict = grad_attr_number_to_dict(p->attribute);
                 if (dict) {
-                        if (!(dict->prop & AF_RHS(cf_file))) {
+                        if (!(dict->prop & GRAD_AF_RHS(cf_file))) {
                                 grad_log_loc(L_ERR, loc,
 					  _("attribute %s not allowed in RHS"),
 					     dict->name);
