@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2006,
+   2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -128,7 +129,7 @@ radius_verify_digest(REQUEST *req)
         secretlen = strlen(radreq->request->secret);
 
         recvbuf = grad_emalloc(len + secretlen);
-        memcpy(recvbuf, req->rawdata, len + secretlen);
+        memcpy(recvbuf, req->rawdata, len);
         
         /* Older clients have the authentication vector set to
            all zeros. Return `1' in that case. */
@@ -390,8 +391,8 @@ radius_req_update(void *req_ptr, void *data_ptr)
 	req->server_id = upd->proxy_id;
 	req->realm = grad_realm_lookup_name(upd->realmname);
 	req->server_no = upd->server_no;
-	debug(1, ("Update request %d: proxy_id=%d, realm=%s, server_no=%d",
-		  req->request->id,upd->proxy_id,upd->realmname,upd->server_no));
+	GRAD_DEBUG4(1, "Update request %d: proxy_id=%d, realm=%s, server_no=%d",
+		  req->request->id,upd->proxy_id,upd->realmname,upd->server_no);
 }
 
 void
@@ -473,13 +474,13 @@ radius_respond(REQUEST *req)
 
 	radiusd_sql_clear_cache();
 
+        /* Add any specific attributes for this username. */
+        hints_setup(radreq);
+
 	if (radreq->request->code == RT_ACCESS_REQUEST
 	    && rad_auth_check_username(radreq, req->fd))
 	    return 1;
 	
-        /* Add any specific attributes for this username. */
-        hints_setup(radreq);
-
         /* Check if we support this request */
         switch (radreq->request->code) {
         case RT_ACCESS_REQUEST:
@@ -533,6 +534,7 @@ radius_respond(REQUEST *req)
 		radius_status_server(radreq, req->fd);
 		break;
 					
+
         default:
                 stat_inc(acct, radreq->request->ipaddr, num_unknowntypes);
                 grad_log_req(L_NOTICE, radreq->request,
