@@ -1,11 +1,11 @@
 ;;;; This file is part of GNU Radius.
-;;;; Copyright (C) 2001,2002,2003 Free Software Foundation, Inc.
+;;;; Copyright (C) 2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 ;;;;
 ;;;; Written by Sergey Poznyakoff
 ;;;;
 ;;;; GNU Radius is free software; you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
-;;;; the Free Software Foundation; either version 2 of the License, or
+;;;; the Free Software Foundation; either version 3 of the License, or
 ;;;; (at your option) any later version.
 ;;;;
 ;;;; GNU Radius is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
 ;;;; along with GNU Radius; if not, write to the Free Software
 ;;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 ;;;;
-;;;; $Id: ttl.scm,v 1.10 2003/11/08 09:48:11 gray Exp $
+;;;; $Id: ttl.scm,v 1.17 2007/06/27 12:53:57 gray Exp $
 
 ;;;; This is a framework for computing the Session-Timeout attribute on
 ;;;; the fly. The module queries a remote host about a timeout value for
@@ -46,17 +46,25 @@
 ;;;; +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 ;;;;
 ;;;; Code is ignored. String contains a timeout value for the user
-;;;; converted to ASCII. If it starts with '-', no timeout is set.
+;;;; converted to ASCII (null-terminated). If it starts with '-', no
+;;;; timeout is set.
 ;;;;
 ;;;; usage:
 ;;;;
+;;;; raddb/config (section 'guile'):
+;;;;
+;;;; load-module "ttl" -dest-ip <ip-addr> -dest-port <port>;
+;;;; 
 ;;;; raddb/hints:
 ;;;; DEFAULT    NULL  Scheme-Acct-Procedure = "ttl-session"
 ;;;;
 ;;;; raddb/users:
 ;;;; BEGIN      NULL  Scheme-Procedure = "ttl-query", Fall-Through = Yes
 
-(use-modules (ice-9 format))
+(define-module (ttl)
+  :use-module (radiusd)
+  :use-module (gnuradius)
+  :use-module (ice-9 format))
 
 (define ttl-source-ip-address INADDR_ANY)
 (define ttl-source-port 0)
@@ -64,6 +72,80 @@
 (define ttl-dest-port 0)
 (define ttl-max-retry 1)
 (define ttl-timeout 3)
+(define ttl-debug-enabled #f)
+
+(define (host-spec? x)
+  (and
+   (pair? x)
+   (number? (car x))
+   (number? (cdr x)) (= (cdr x) #xffffffff)))
+
+(define-public (ttl-init . rest)
+  (call-with-current-continuation
+   (lambda (stop)
+     (letrec ((value #f)
+	      (checkval (lambda (key pred)
+			  (cond
+			   ((not value)
+			    (rad-log L_ERR
+				     (format
+				      #f
+				      "ttl-init: No value specified for keyword ~A"
+				      key))
+			    (stop))
+			   ((not (pred value))
+			    (rad-log L_ERR
+				     (format
+				      #f
+				      "ttl-init: Invalid data type specified for keyword ~A"
+				      key))
+			    (stop))))))
+       (for-each
+	(lambda (key)
+	  (cond
+	   ((keyword? key)
+	    (case key
+	      ((#:debug)
+	       (set! ttl-debug-enabled #t))
+	      ((#:dest-ip-address #:dest-ip)
+	       (checkval key host-spec?)
+	       (set! ttl-dest-ip-address (car value)))
+	      ((#:dest-port)
+	       (checkval key number?)
+	       (set! ttl-dest-port value))
+	      ((#:source-ip-address #:source-ip)
+	       (checkval key host-spec?)
+	       (set! ttl-source-ip-address (car value)))
+	      ((#:source-port)
+	       (checkval key number?)
+	       (set! ttl-source-port value))
+	      ((#:max-retry)
+	       (checkval key number?)
+	       (set! ttl-max-retry value))
+	      ((#:timeout)
+	       (checkval key number?)
+	       (set! ttl-timeout value))
+	      (else
+		(rad-log L_ERR
+			 (string-append
+			  (format #f
+				  "ttl-init: Undefined keyword ~A"
+				  key)))
+		(stop)))
+	    (set! value #f))
+	   ((not value)
+	    (set! value key))
+	   (else
+	    (rad-log L_ERR
+		     (format #f "ttl-init: stray argument near ~A" key)))))
+	(reverse rest))))))
+
+(define (ttl-debug fmt . rest)
+  (if ttl-debug-enabled
+      (rad-log L_DEBUG (apply format
+			      (append
+			       (list #f fmt)
+			       rest)))))
 
 (define (ttl-make-header code user-name)
   (let ((hdr (make-string 2 (integer->char 0))))
@@ -82,11 +164,23 @@
 (define (ttl-reply-string packet)
   (substring packet 2 (1- (ttl-reply-length packet))))
 
+(define (wait-input fd ttl-timeout)
+  (call-with-current-continuation
+   (lambda (return)
+     (do ()
+	 (#f)
+       (catch 'system-error
+	      (lambda ()
+		(return (select (list fd) '() '() ttl-timeout)))
+	      (lambda (key . args)
+		(if (not (= (car (list-ref args 3)) EINTR))
+		    (apply throw key args))))))))
+
 (define (ttl-message code user-name)
   (let ((packet (ttl-make-packet code user-name))
         (fd (socket AF_INET SOCK_DGRAM 0))
         (ttl #f))
-    (rad-log L_DEBUG (format #f "Sending ~A, ~A" code user-name))
+    (ttl-debug "Sending ~A, ~A" code user-name)
     (cond
      ((not fd)
       (rad-log L_ERR "can't open socket for ttl exchange"))
@@ -99,17 +193,19 @@
               ((or ttl (>= i ttl-max-retry)) #f)
 
               (sendto fd packet AF_INET ttl-dest-ip-address ttl-dest-port)
-              (let ((sel (select (list fd) '() '() ttl-timeout)))
+	      
+              (let ((sel (wait-input fd ttl-timeout)))
                 (cond
                  ((not (null? (car sel)))
                   (let* ((ret (recvfrom! fd packet))
                          (length (car ret)))
-		    (rad-log L_DEBUG (format #f "length ~A" length))
-		    (rad-log L_DEBUG (format #f "reply-length ~A"
-					     (ttl-reply-length packet)))
+		    (ttl-debug "reply packet length ~A, reported length ~A"
+			       length
+			       (ttl-reply-length packet))
                     (if (not
                          (or
-                          (< length 2)
+                          (< length 4) ;; Remote party should send us
+			               ;; at least one significant character
                           (not (= (ttl-reply-length packet) length))))
                         (cond
                          ((or (char=? code #\+) (char=? code #\-))
@@ -120,8 +216,7 @@
                                       #\-)
                             (set! ttl #t)) ;; Force exit from loop
                            (else
-			    (rad-log L_DEBUG (format #f "text ~A"
-						     (ttl-reply-string packet)))
+			    (ttl-debug "text ~A" (ttl-reply-string packet))
                             (let ((num (string->number
                                         (ttl-reply-string packet))))
                               (if (not num)
@@ -136,13 +231,13 @@
           ;;FIXME: more verbose
           (rad-log L_ERR (format #f "~A" args))))
       (close-port fd)))
-    (rad-log L_DEBUG (format #f "returning ~A" ttl))
+    (ttl-debug "returning ~A" ttl)
     ttl))
 
-(define (ttl-query req check reply)
+(define-public (ttl-query req check reply)
   (let* ((user-pair (assoc "User-Name" req))
          (ttl-pair (assoc "Session-Timeout" reply)))
-    (display "ttl-query:")(display user-pair)(display ttl-pair)(newline)
+    ;(display "ttl-query:")(display user-pair)(display ttl-pair)(newline)
     (cond
      ((not user-pair)
       #f)
@@ -167,7 +262,7 @@
           (rad-log L_NOTICE "Ignoring returned ttl")
           #t)))))))
 
-(define (ttl-session req)
+(define-public (ttl-session req)
   (let* ((user-pair (assoc "User-Name" req))
          (acct-pair (assoc "Acct-Status-Type" req)))
     (cond
@@ -179,5 +274,5 @@
       (ttl-message #\- (cdr user-pair)))))
   #t)
 
-;;;; Put any application-specific definifions here:
+;;;; End of ttl.scm
 
