@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
  
    GNU Radius is distributed in the hope that it will be useful,
@@ -36,29 +37,8 @@
 #include <radtest.h>
 #include <radius/argcv.h>
 
-grad_symtab_t *vartab;
-int verbose;
-extern int grad_client_debug;
-grad_server_queue_t *srv_queue;
-int reply_code;
-grad_avp_t *reply_list;
-int abort_on_failure = 0;
-
-void init_symbols();
-static void assign(char *);
-
-int x_argmax;
-int x_argc;
-char **x_argv;
-
-int quick = 0;
-char *filename = NULL;
-char *server = NULL;
-int retry = 0;
-int timeout = 0;
-
 const char *argp_program_version = "radtest (" PACKAGE ") " VERSION;
-static char doc[] = N_("send arbitrary radius packets");
+static char doc[] = N_("Radius client shell");
 
 static struct argp_option options[] = {
         {NULL, 0, NULL, 0,
@@ -68,11 +48,9 @@ static struct argp_option options[] = {
         {"debug", 'x', "DEBUGSPEC", 0,
          N_("set debugging level"), 0},
         {"file", 'f', N_("FILE"), 0,
-         N_("Read input from FILE. When this option is used, all unknown"
-         " options in the form --VAR=VALUE are treated as variable"
-         " assignments"), 0},
-        {"quick", 'q', NULL, 0,
-         "FIXME: quick mode", 0},
+         N_("Read input from FILE. Stops further processing of the command line."), 0},
+        {"quick", 'q', NULL, 0,     /* FIXME */
+         "Do not read the configuration file", 0},
         {"retry", 'r', N_("NUMBER"), 0,
          N_("set number of retries"), 0},
         {"server", 's', N_("SERVER"), 0,
@@ -81,15 +59,54 @@ static struct argp_option options[] = {
          N_("set timeout"), 0},
         {"verbose", 'v', NULL, 0,
          N_("verbose mode"), 0},
+	{"no-interactive", 'i', NULL, 0,
+	 N_("disable interactive mode"), 0 },
+	{"dry-run", 'n', NULL, 0,
+	 N_("Check the input file syntax and exit"), 0 },
         {NULL, 0, NULL, 0, NULL, 0}
 };
 
+int verbose;                   /* -v (--verbose) option */
+int quick = 0;                 /* -q (--quick). A misnomer! */
+char *filename = NULL;         /* Name of the input file to execute.
+				  -f (--file) */
+/* These three are set from -s (--server) option */
+char *server = NULL;           /* Server name */
+int retry = 0;                 /* Retry count */
+int timeout = 0;               /* Timeout */
+
+int disable_readline;          /* --no-interactive */
+int dry_run;                   /* --dry-run (-n) */
+
+static void
+assign(char *s)
+{
+        char *p;
+        radtest_variable_t *var;
+        radtest_datum_t datum;
+        radtest_data_type type = rtv_undefined;
+        
+        p = strchr(s, '=');
+        if (!p) {
+                fprintf(stderr, _("assign: expected `='\n"));
+                return;
+        }
+        *p++ = 0;
+
+        type = parse_datum(p, &datum);
+        if (type == rtv_undefined)
+                return;
+        var = (radtest_variable_t*)grad_sym_install(vartab, s);
+        var->type = type;
+        var->datum = datum;
+}
+
 static error_t
 parse_opt(int key, char *arg, struct argp_state *state)
 {
         switch (key) {
         case 'a':
-                assign(optarg);
+                assign(arg);
                 break;
 		
         case 'q':
@@ -97,29 +114,39 @@ parse_opt(int key, char *arg, struct argp_state *state)
                 break;
 		
         case 'r':
-                retry = strtol(optarg, NULL, 0);
+                retry = strtol(arg, NULL, 0);
                 break;
 		
         case 's':
-                server = optarg;
+                server = arg;
                 break;
 		
         case 'f':
-                filename = optarg;
+                filename = arg;
+		*(int *)state->input = state->next;
+		state->next = state->argc;
                 break;
+
+	case 'i':
+		disable_readline = 1;
+		break;
+
+	case 'n':
+		dry_run = 1;
+		break;
 		
         case 't':
-                timeout = strtol(optarg, NULL, 0);
+                timeout = strtol(arg, NULL, 0);
                 break;
 		
         case 'x':
-                set_debug_levels(optarg);
+                grad_set_debug_levels(arg);
                 break;
 		
         case 'v':
                 verbose++;
-		set_module_debug_level("radpdu", 100);
-		set_module_debug_level("client", 100);
+		grad_set_module_debug_level("radpdu", 100);
+		grad_set_module_debug_level("client", 100);
                 break;
 
         default:
@@ -133,30 +160,66 @@ static struct argp argp = {
         parse_opt,
         NULL,
         doc,
-        rad_common_argp_child,
-        NULL, NULL
+        grad_common_argp_child,
+        NULL,
+	NULL
 };
 
+int
+radtest_parse_options(int argc, char **argv)
+{
+        int index;
+	return argp_parse (&argp, argc, argv, ARGP_NO_EXIT, NULL, &index);
+}
+
+grad_server_queue_t *srv_queue; /* Server queue */
+
+grad_symtab_t *vartab;          /* Variable table */
+grad_symtab_t *functab;         /* Function table */
+ 
+int reply_code;                 /* Last radius reply code */
+grad_avp_t *reply_list;         /* Last radius reply pairs */
+
+grad_list_t *toplevel_env;      /* Top level environment */
+
+static void
+init_symbols()
+{
+        radtest_variable_t *var;
+        
+        vartab = grad_symtab_create(sizeof(radtest_variable_t), NULL);
+        var = (radtest_variable_t*) grad_sym_install(vartab, "REPLY_CODE");
+        var->type = rtv_integer;
+        var = (radtest_variable_t*) grad_sym_install(vartab, "REPLY");
+        var->type = rtv_avl;
+	var = (radtest_variable_t*) grad_sym_install(vartab, "SOURCEIP");
+	var->type = rtv_ipaddress;
+
+	functab = grad_symtab_create(sizeof(radtest_function_t), NULL);
+}
+
 int
 main(int argc, char **argv)
 {
         char *p;
-        int index;
-	Variable *var;
+        int index, argind;
+	radtest_variable_t *var;
 	
         grad_app_setup();
         init_symbols();
 
-        index = argc;
-        if (grad_argp_parse(&argp, &argc, &argv, 0, &index, NULL))
+        index = 0;
+        if (grad_argp_parse(&argp, &argc, &argv, ARGP_IN_ORDER, &argind, &index))
                 return 1;
-
+	if (index == 0)
+		index = argind;
+	
         argv += index;
         argc -= index;
 
         set_yydebug();
         grad_path_init();
-	srand(time(NULL));
+	srand(time(NULL)+getpid());
 	
         if (grad_dict_init()) {
                 grad_log(L_ERR, _("error reading dictionary file"));
@@ -167,7 +230,7 @@ main(int argc, char **argv)
         if (!srv_queue)
                 return 1;
 
-	var = (Variable*)grad_sym_lookup(vartab, "SOURCEIP");
+	var = (radtest_variable_t*)grad_sym_lookup(vartab, "SOURCEIP");
 	var->datum.ipaddr = srv_queue->source_ip;
 		
 	if (timeout)
@@ -179,7 +242,7 @@ main(int argc, char **argv)
                 int i, argc;
                 char **argv;
 
-                if (argcv_get(server, ":", NULL, &argc, &argv)) {
+                if (grad_argcv_get(server, ":", NULL, &argc, &argv)) {
                         grad_log(L_ERR, _("can't parse server definition"));
                         exit(1);
                 }
@@ -202,9 +265,11 @@ main(int argc, char **argv)
                                         exit(1);
                                 }
                                 break;
+				
                         case 2:
                                 serv.secret = argv[i];
                                 break;
+				
                         case 4:
                                 serv.port[0] = strtol(argv[i], &p, 0);
                                 if (*p) {
@@ -214,6 +279,7 @@ main(int argc, char **argv)
                                         break;
                                 }
                                 break;
+				
                         case 6:
                                 serv.port[1] = strtol(argv[i], &p, 0);
                                 if (*p) {
@@ -223,6 +289,7 @@ main(int argc, char **argv)
                                         break;
                                 }
                                 break;
+				
                         default:
                                 if (argv[i][0] != ':') {
                                         grad_log(L_ERR,
@@ -240,7 +307,7 @@ main(int argc, char **argv)
                         serv.port[1] = DEF_ACCT_PORT;
 		grad_client_append_server(srv_queue,
 					  grad_client_alloc_server(&serv));
-                argcv_free(argc, argv);
+                grad_argcv_free(argc, argv);
         }
 
         if (grad_list_count(srv_queue->servers) == 0) {
@@ -248,83 +315,38 @@ main(int argc, char **argv)
                          _("No servers specfied. Use -s option.\n"));
                 exit(1);
         }
-        
-        x_argmax = argc + 2;
-        x_argv = grad_emalloc(sizeof(x_argv[0]) * x_argmax);
-        x_argc = 0;
-        x_argv[x_argc++] = filename;
+
+	toplevel_env = grad_list_create();
+	radtest_env_add_string(toplevel_env, filename ? filename : "");
 
         for (; argc; argv++, argc--) {
-                if (argv[0][0] == '-'
-                    && argv[0][1] == '-'
-                    && (p = strchr(argv[0], '=')) != NULL
-                    && !(p > argv[0] && p[-1] == '\\')) 
-                        assign(argv[0]+2);
-                else if ((p = strchr(*argv, '=')) != NULL &&
-                         !(p > *argv && p[-1] == '\\')) 
+                if ((p = strchr(*argv, '=')) != NULL &&
+		    !(p > *argv && p[-1] == '\\')) 
                         assign(*argv);
-                else 
-                        x_argv[x_argc++] = *argv;
+                else
+			radtest_env_add_string(toplevel_env, *argv);
         }
-        x_argv[x_argc++] = NULL;
-        
-        if (open_input(filename))
-                return 1;
-        return yyparse();
+
+	return read_and_eval(filename);
 }
 
-void
-init_symbols()
-{
-        Variable *var;
-        
-        vartab = grad_symtab_create(sizeof(Variable), NULL);
-        var = (Variable*) grad_sym_install(vartab, "REPLY_CODE");
-        var->type = Integer;
-        var = (Variable*) grad_sym_install(vartab, "REPLY");
-        var->type = Vector;
-	var = (Variable*) grad_sym_install(vartab, "SOURCEIP");
-	var->type = Ipaddress;
-}
+
 
-void
-assign(char *s)
+radtest_data_type
+parse_datum(char *p, radtest_datum_t *dp)
 {
-        char *p;
-        Variable *var;
-        union datum datum;
-        int type = Undefined;
-        
-        p = strchr(s, '=');
-        if (!p) {
-                fprintf(stderr, _("assign: expected `='\n"));
-                return;
-        }
-        *p++ = 0;
-
-        type = parse_datum(p, &datum);
-        if (type == Undefined)
-                return;
-        var = (Variable*)grad_sym_install(vartab, s);
-        var->type = type;
-        var->datum = datum;
-}
-
-int
-parse_datum(char *p, union datum *dp)
-{
-        int type = Undefined;
+        radtest_data_type type = rtv_undefined;
         int length;
         
         if (*p == '"') {
                 length = strlen(++p);
                 if (length == 0 || p[length-1] != '"') {
                         fprintf(stderr, _("assign: missing closing quote\n"));
-                        return Undefined;
+                        return rtv_undefined;
                 }
                 p[length-1] = 0;
                 
-                type = String;
+                type = rtv_string;
                 dp->string = grad_estrdup(p);
         } else if (isdigit(*p)) {
                 char *endp;
@@ -332,54 +354,31 @@ parse_datum(char *p, union datum *dp)
                 /* This can be either an integer or an IP address */
                 dp->number = strtol(p, &endp, 0);
                 if (*endp == 0) {
-                        type = Integer;
+                        type = rtv_integer;
                 } else {
                         /* IP address */
                         if ((dp->ipaddr = grad_ip_gethostaddr(p)) != 0)
-                                type = Ipaddress;
+                                type = rtv_ipaddress;
                         else {
                                 fprintf(stderr, _("assign: invalid IP address: %s\n"), p);
-                                return Undefined;
+                                return rtv_undefined;
                         }
                 } 
         } else if (strchr(p, '.')) {
                 /* IP address */
                 if ((dp->ipaddr = grad_ip_gethostaddr(p)) != 0)
-                        type = Ipaddress;
+                        type = rtv_ipaddress;
                 else {
                         fprintf(stderr, _("assign: invalid IP address: %s\n"), p);
-                        return Undefined;
+                        return rtv_undefined;
                 }
         } else {
-                type = String;
+                type = rtv_string;
                 dp->string = grad_estrdup(p);
         }
         return type;
 }
 
-char *
-print_ident(Variable *var)
-{
-        char buf[64];
-        switch (var->type) {
-        case Undefined:
-                return grad_estrdup("UNDEFINED");
-                break;
-        case Integer:
-                sprintf(buf, "%d", var->datum.number);
-                return grad_estrdup(buf);
-        case Ipaddress:
-                grad_ip_iptostr(var->datum.ipaddr, buf);
-                return grad_estrdup(buf);
-        case String:
-                return grad_estrdup(var->datum.string);
-                break;
-        case Vector:
-                return grad_estrdup("VECTOR");
-        }
-	return NULL;
-}
-
 void
 print_pairs(FILE *fp, grad_avp_t *pair)
 {
@@ -396,133 +395,135 @@ print_pairs(FILE *fp, grad_avp_t *pair)
 }
 
 void
-var_print(Variable *var)
+var_print(radtest_variable_t *var)
 {
-        char buf[DOTTED_QUAD_LEN];
+        char buf[GRAD_IPV4_STRING_LENGTH];
         if (!var)
                 return;
         switch (var->type) {
-        case Undefined:
+        case rtv_undefined:
                 printf("UNDEFINED");
                 break;
-        case Integer:
-                printf("%d", var->datum.number);
+		
+        case rtv_integer:
+                printf("%ld", var->datum.number);
                 break;
-        case Ipaddress:
+		
+        case rtv_ipaddress:
                 printf("%s", grad_ip_iptostr(var->datum.ipaddr, buf));
                 break;
-        case String:
+
+	case rtv_bstring:
+	{
+		int len = grad_format_string_visual(NULL, 3,
+						    var->datum.bstring.ptr,
+						    var->datum.bstring.length);
+		char *pbuf = grad_emalloc(len+1);
+		grad_format_string_visual(pbuf, 3,
+					  var->datum.bstring.ptr,
+					  var->datum.bstring.length);
+		printf("%s", pbuf);
+		grad_free(pbuf);
+	}
+		break;
+		       
+        case rtv_string:
                 printf("%s", var->datum.string);
                 break;
-        case Vector:
-                printf("{");
-                print_pairs(stdout, var->datum.vector);
-                printf("}");
-                break;
-        case Builtin:
-                var->datum.builtin.print();
+		
+        case rtv_avl:
+                printf("(");
+                print_pairs(stdout, var->datum.avl);
+                printf(")");
                 break;
+
+	case rtv_pairlist:
+		abort();
         }
 }
 
 int
-var_free(Variable *var)
+var_free(radtest_variable_t *var)
 {
         switch (var->type) {
-        case String:
+        case rtv_string:
                 grad_free(var->datum.string);
                 break;
-        case Vector:
-                grad_avl_free(var->datum.vector);
+		
+        case rtv_avl:
+                grad_avl_free(var->datum.avl);
                 break;
+		
+	default:
+		break;
         }
+	return 0;
 }
 
 void
-tempvar_free(Variable *var)
-{
-	if (var) {
-		if (var->name)
-			return; /* named variables are not freed */
-		var_free(var);
-	}
-}
-
-void
-radtest_send(int port, int code, Variable *var, grad_symtab_t *cntl)
+radtest_send(int port, int code, grad_avp_t *avl, grad_symtab_t *cntl)
 {
         grad_request_t *auth;
-	Variable *p;
-	grad_avp_t *pair;
+	radtest_variable_t *p;
 	
         if (reply_list)
                 grad_avl_free(reply_list);
         reply_list = NULL;
         reply_code = 0;
         
-        if (var) {
-		if (var->type != Vector) {
-			parse_error(_("wrong datatype: expected vector"));
-			return;
-		}
-		pair = var->datum.vector;
-	} else
-		pair = NULL;
-
 	if (!cntl) {
-		auth = grad_client_send(srv_queue, port, code, pair);
+		auth = grad_client_send(srv_queue, port, code, avl);
 	} else {
 		int id;
-		u_char vector[AUTH_VECTOR_LEN];
+		u_char authenticator[GRAD_AUTHENTICATOR_LENGTH];
 		int sflags = 0;
 		int retry = 1;
-		Variable *delay = (Variable*)grad_sym_lookup(cntl, "delay");
+		radtest_variable_t *delay = (radtest_variable_t*)grad_sym_lookup(cntl, "delay");
 		
-		p = (Variable*)grad_sym_lookup(cntl, "repeat");
+		p = (radtest_variable_t*)grad_sym_lookup(cntl, "repeat");
 		if (p)
 			retry = p->datum.number;
-		p = (Variable*)grad_sym_lookup(cntl, "id");
+		p = (radtest_variable_t*)grad_sym_lookup(cntl, "id");
 		if (p) {
 			sflags |= RADCLT_ID;
 			id = p->datum.number;
 		}
-		p = (Variable*)grad_sym_lookup(cntl, "keepauth");
+		p = (radtest_variable_t*)grad_sym_lookup(cntl, "keepauth");
 		if (p && p->datum.number) 
 			sflags |= RADCLT_AUTHENTICATOR;
 		auth = grad_client_send0(srv_queue,
 					 port,
 					 code,
-					 pair,
+					 avl,
 					 0,
 					 &id,
-					 vector);
+					 authenticator);
 		while (--retry) {
 			if (delay)
 				sleep(delay->datum.number);
 			auth = grad_client_send0(srv_queue,
 						 port,
 						 code,
-						 var->datum.vector,
+						 avl,
 						 sflags,
 						 &id,
-						 vector);
+						 authenticator);
 		}
 	}
 
 	if (!auth)
 		return;
         reply_code = auth->code;
-        var = (Variable*)grad_sym_lookup(vartab, "REPLY_CODE");
-        var->type = Integer;
-        var->datum.number = reply_code;
+        p = (radtest_variable_t*)grad_sym_lookup(vartab, "REPLY_CODE");
+        p->type = rtv_integer;
+        p->datum.number = reply_code;
 
-        reply_list = grad_client_decrypt_pairlist(grad_avl_dup(auth->request),
-						  auth->vector, auth->secret);
+        reply_list = grad_client_decrypt_pairlist(grad_avl_dup(auth->avlist),
+						  auth->authenticator, auth->secret);
 
-        var = (Variable*)grad_sym_lookup(vartab, "REPLY");
-        var->type = Vector;
-        var->datum.vector = NULL;
-        var->datum.vector = reply_list;
+        p = (radtest_variable_t*)grad_sym_lookup(vartab, "REPLY");
+        p->type = rtv_avl;
+        p->datum.avl = reply_list;
         grad_request_free(auth);
 }
 
@@ -566,33 +567,44 @@ comp_op(enum grad_operator op, int result)
 }
 
 int
-compare_lists(grad_avp_t *reply, grad_avp_t *sample)
+compare_lists(grad_avp_t *reply_list, grad_avp_t *sample)
 {
         int result = 0;
+	grad_avp_t *reply = grad_avl_dup(reply_list);
         
         for (; sample && result == 0; sample = sample->next) {
-                grad_avp_t *p;
+                grad_avp_t *p, *prev = NULL;
 
                 if (sample->attribute > 255)
                         continue;
                 for (p = reply; p && p->attribute != sample->attribute;
-                     p = p->next)
+                     prev = p, p = p->next)
                         ;
                 if (!p)
                         return -1;
                 switch (p->type) {
-                case TYPE_STRING:
+                case GRAD_TYPE_STRING:
                         result = strcmp(sample->avp_strvalue, p->avp_strvalue);
                         break;
-                case TYPE_INTEGER:
-                case TYPE_IPADDR:
+			
+                case GRAD_TYPE_INTEGER:
+                case GRAD_TYPE_IPADDR:
                         result = sample->avp_lvalue - p->avp_lvalue;
                         break;
+			
                 default:
                         result = -1;
                 }
                 result = comp_op(sample->operator, result);
+		if (result == 0) {
+			if (!prev)
+				reply = p->next;
+			else
+				prev->next = p->next;
+			grad_avp_free(p);
+		}
         }
+	grad_avl_free(reply);
         return result;
 }
 
