@@ -1,12 +1,12 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,
-   2006 Free Software Foundation, Inc.
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -55,7 +55,7 @@ do_mysql_query(struct sql_connection *conn, char *query)
         int    i;
         MYSQL *mysql;
         
-        GRAD_DEBUG(1, ("called with %s", query));
+        GRAD_DEBUG1(1, "called with %s", query);
                 
         for (i = 0; i < 10; i++) {      /* Try it 10 Times */
                 if (!conn->connected) {
@@ -65,7 +65,7 @@ do_mysql_query(struct sql_connection *conn, char *query)
                 }
                 mysql = (MYSQL*)conn->data;
                 ret = mysql_query(mysql, query);
-                GRAD_DEBUG(1, ("MYSQL query returned %d", ret));
+                GRAD_DEBUG1(1, "MYSQL query returned %d", ret);
                 if (!ret) 
                         return ret;
                 
@@ -76,7 +76,7 @@ do_mysql_query(struct sql_connection *conn, char *query)
 			return ret;
 		}
         }
-        GRAD_DEBUG(1,("FAILURE"));
+        GRAD_DEBUG(1, "FAILURE");
         grad_log(L_ERR, "[MYSQL] %s", _("gave up on connect"));
         return ret;
 }
@@ -115,7 +115,7 @@ rad_mysql_reconnect(int type, struct sql_connection *conn)
 		return -1;
 	}
 
-	GRAD_DEBUG(1, ("connected to %s", conn->cfg->server));
+	GRAD_DEBUG1(1, "connected to %s", conn->cfg->server);
 	conn->connected++;
         return 0;
 }
@@ -154,7 +154,7 @@ rad_mysql_getpwd(struct sql_connection *conn, char *query)
         if (!conn)
                 return NULL;
 
-        GRAD_DEBUG(1, ("query: %s", query));
+        GRAD_DEBUG1(1, "query: %s", query);
 
         if (do_mysql_query(conn, query))
                 return NULL;
@@ -214,7 +214,7 @@ rad_mysql_exec(struct sql_connection *conn, char *query)
         if (!conn)
                 return NULL;
         
-        GRAD_DEBUG(1, ("query: %s", query));
+        GRAD_DEBUG1(1, "query: %s", query);
         
         if (do_mysql_query(conn, query))
                 return NULL;
@@ -223,7 +223,7 @@ rad_mysql_exec(struct sql_connection *conn, char *query)
                 return NULL;
 
         nrows = mysql_num_rows(result);
-        GRAD_DEBUG(1, ("got %d rows", nrows));
+        GRAD_DEBUG1(1, "got %d rows", nrows);
         if (nrows == 0) {
                 mysql_free_result(result);
                 return NULL;
