@@ -1,12 +1,12 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,
-   2006 Free Software Foundation, Inc.
+   2006,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -100,7 +100,7 @@ rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
         if (!conn || !conn->data)
                 return -1;
 
-        GRAD_DEBUG(1, ("query: %s", query));
+        GRAD_DEBUG1(1, "query: %s", query);
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
@@ -114,7 +114,7 @@ rad_postgres_query(struct sql_connection *conn, char *query, int *return_count)
         
         stat = PQresultStatus(res);
 
-        GRAD_DEBUG(1, ("status: %s", PQresStatus(stat)));
+        GRAD_DEBUG1(1, "status: %s", PQresStatus(stat));
 
 	switch (stat) {
 	case PGRES_COMMAND_OK:
@@ -170,7 +170,7 @@ rad_postgres_getpwd(struct sql_connection *conn, char *query)
         if (!conn || !conn->data)
                 return NULL;
 
-        GRAD_DEBUG(1, ("query: %s", query));
+        GRAD_DEBUG1(1, "query: %s", query);
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
@@ -184,9 +184,7 @@ rad_postgres_getpwd(struct sql_connection *conn, char *query)
         
         stat = PQresultStatus(res);
 
-        GRAD_DEBUG(1,
-              ("status: %s",
-              PQresStatus(stat)));
+        GRAD_DEBUG1(1, "status: %s", PQresStatus(stat));
 
         if (stat == PGRES_TUPLES_OK) {
                 int ntuples = PQntuples(res);
@@ -248,7 +246,7 @@ rad_postgres_exec(struct sql_connection *conn, char *query)
         if (!conn || !conn->data)
                 return NULL;
 
-        GRAD_DEBUG(1, ("query: %s", query));
+        GRAD_DEBUG1(1, "query: %s", query);
         
         res = PQexec((PGconn*)conn->data, query);
         if (res == NULL) {
@@ -262,9 +260,7 @@ rad_postgres_exec(struct sql_connection *conn, char *query)
         
         stat = PQresultStatus(res);
 
-        GRAD_DEBUG(1,
-              ("status: %s",
-              PQresStatus(stat)));
+        GRAD_DEBUG1(1, "status: %s", PQresStatus(stat));
 
         if (stat != PGRES_TUPLES_OK) {
                 PQclear(res);
